@@ -1,12 +1,14 @@
 from . import queue
 from .extension import ExtensionBaseClass
 import azure.storage.queue
+import azure.function
 
 
 class QueueManager:
     def __init__(
         self,
         queue: queue.QueueClient,
+        has_queue_trigger: bool = False,
         input_transformer: ExtensionBaseClass | None = None,
         output_transformer: ExtensionBaseClass | None = None,
     ):
@@ -27,7 +29,7 @@ class QueueManager:
         This is a wrapper for azure.storage.queue.QueueClient.peek_messages
         """
 
-        return self.queue.peek_messages(max_messages=max_messages)
+        return self.queue.client.peek_messages(max_messages=max_messages)
 
     def preview_message(
         self,
@@ -37,9 +39,10 @@ class QueueManager:
         """
 
         message = self.list_messages(1)[0]
+        print(message)
 
         if self.output_transformer:
-            transformed_message = self.output_transformer.transform_out([message]).next()
+            transformed_message = self.output_transformer.transform_preview(message)
             
         else:
             transformed_message = message.content
@@ -57,14 +60,13 @@ class QueueManager:
         If preview_mode is True, the message will be peeked and the deque_count will not change.
         If delere_after is True, the message will be deleted after it is processed.
         """
-        message = self.queue.receive_message()
+        message = self.queue.client.receive_message()
 
         # Transform the message
-        if self.output_transformer:
-            transformed_message = self.output_transformer.transform_out([message]).next()
+        self.transform_message(message)
 
         if not preview_mode and delete_after:
-            self.queue.delete_message(message.id, message.pop_receipt)
+            self.queue.client.delete_message(message.id, message.pop_receipt)
 
         return message
 
@@ -74,24 +76,39 @@ class QueueManager:
         delete_after: bool = True,
     ):
         """Loads the next messages in the queue."""
-        output_messages = self.queue.receive_messages(count)
-        output = self.output_transformer.transform_many(output_messages)
+        output_messages = self.queue.client.receive_messages(max_messages=count)
+        if self.output_transformer:
+            output = self.output_transformer.transform_out(output_messages)
+        
+        else:
+            output = output_messages
         
         if delete_after:
             for message in output_messages:
-                self.queue.delete_message(message.id, message.pop_receipt)
+                self.queue.client.delete_message(message.id, message.pop_receipt)
 
         return output
 
     def queue_messages(self, messages: list[str] | None = None) -> azure.storage.queue.QueueMessage:
+        """
+        enqueue the messages into the queue_client.
+        If there is a transformer, transform using the `transform_in` method for the extensions
+        """
+
         if self.input_transformer:
             messages = self.input_transformer.transform_in()
 
-        print(f"adding {messages=} to {self.queue=}") 
-
         return [self.queue.client.send_message(content=msg) for msg in messages]
 
 
+    def transform_message(self, message: azure.functions.QueueMessage) -> any:
+        logging.info(f"Transforming message {message=}")
+        if self.output_transformer:
+            return self.output_transformer.transform_out([message.get_body().decode('utf-8')]).next()
+
+        logging.info("No Output Transformer. Returning message %s", message)
+        return message
+
     # TODO: Add a validator for the message_transformer. This ensures that the messages_will be processed correctly.
 
     # TODO: Add input tranformers. This will allow the user to transform the input before it is sent to the queue.
